@@ -10,10 +10,13 @@ import crowdsource.psf as psfmod
 from astropy.io import fits
 from astropy import wcs
 from functools import partial
-import crowdsource
+from crowdsource import crowdsource_base
 from scipy.ndimage import zoom
 
-badpixmaskfn = '/n/fink2/www/eschlafly/decam/badpixmasksefs_comp.fits'
+import os
+if 'DECAM_DIR' not in os.environ:
+    decam_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)),"decam_dir")
+    os.environ['DECAM_DIR'] = decam_dir
 
 extrabits = ({'badpix': 2**20,
               'diffuse': 2**21,
@@ -99,7 +102,7 @@ def read_data(imfn, ivarfn, dqfn, extname, badpixmask=None,
             gmsk = galaxy_mask.galaxy_mask(hdr, leda)
             if numpy.any(gmsk):
                 imded |= (gmsk * extrabits['galaxy'])
-                imded |= (gmsk * crowdsource.nodeblend_maskbit)
+                imded |= (gmsk * crowdsource_base.nodeblend_maskbit)
         else:
             if verbose:
                 print("WCSCAL Unsucessful, Skipping galaxy masking...")
@@ -121,8 +124,8 @@ def read_data(imfn, ivarfn, dqfn, extname, badpixmask=None,
 
         if numpy.any(nebmask):
             imded |= (nebmask * extrabits['diffuse'])
-            imded |= (nebmask * (crowdsource.nodeblend_maskbit |
-                                 crowdsource.sharp_maskbit))
+            imded |= (nebmask * (crowdsource_base.nodeblend_maskbit |
+                                 crowdsource_base.sharp_maskbit))
             if verbose:
                 print('Masking nebulosity fraction, %5.2f' % (
                     numpy.sum(nebmask)/1./numpy.sum(numpy.isfinite(nebmask))))
@@ -201,7 +204,7 @@ def process_one_ccd(name, bigdict):
         blist = None
 
     # the actual fit (which has a nested iterative fit)
-    res = crowdsource.fit_im(
+    res = crowdsource_base.fit_im(
         im, psf, ntilex=4, ntiley=2, weight=wt, dq=dq, psfderiv=True,
         refit_psf=True, verbose=verbose, blist=blist, maxstars=320000,
         ccd=name, plot=plot, miniter=miniter, maxiter=maxiter,
@@ -231,7 +234,7 @@ def process_one_ccd(name, bigdict):
     gain = hdr['GAINCRWD']*numpy.ones(len(cat), dtype='f4')
     if prb is not None:
         prnebdat = [
-            crowdsource.extract_im(cat['x'], cat['y'], prb[:, :, i])
+            crowdsource_base.extract_im(cat['x'], cat['y'], prb[:, :, i])
             for i in range(prb.shape[2])]
         prnebnames = ['prN', 'prL', 'prR', 'prE']
         prbexport = zoom(prb, (1/8, 1/8, 1), order=1)
@@ -529,7 +532,6 @@ def correct_sky_offset(im, weight=None):
            (weight[:, half-bdy:half] > 0))
     if numpy.sum(use) == 0:
         return im
-    import crowdsource.psf
     delta = im[:, half+bdy:half:-1] - im[:, half-bdy:half]
     weight = numpy.min([weight[:, half+bdy:half:-1],
                         weight[:, half-bdy:half]], axis=0)
@@ -556,8 +558,8 @@ def mask_very_bright_stars(dq, blist):
         yl, yr = numpy.clip([y-maskrad, y+maskrad], 0,
                             dq.shape[1]-1).astype('i4')
         dq[xl:xr, yl:yr] |= extrabits['brightstar']
-        dq[xl:xr, yl:yr] |= (crowdsource.nodeblend_maskbit |
-                             crowdsource.sharp_maskbit)
+        dq[xl:xr, yl:yr] |= (crowdsource_base.nodeblend_maskbit |
+                             crowdsource_base.sharp_maskbit)
     return dq
 
 
